@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2024 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -20,6 +20,12 @@ def tamper(payload, **kwargs):
 
     >>> tamper("1' AND SLEEP(5)#")
     '1&#39;&#32;AND&#32;SLEEP&#40;5&#41;&#35;'
+    >>> tamper("1&#39;&#32;AND&#32;SLEEP&#40;5&#41;&#35;")
+    '1&#39;&#32;AND&#32;SLEEP&#40;5&#41;&#35;'
     """
 
-    return re.sub(r"[^\w]", lambda match: "&#%d;" % ord(match.group(0)), payload) if payload else payload
+    if payload:
+        payload = re.sub(r"&#(\d+);", lambda match: chr(int(match.group(1))), payload)      # NOTE: https://github.com/sqlmapproject/sqlmap/issues/5203
+        payload = re.sub(r"[^\w]", lambda match: "&#%d;" % ord(match.group(0)), payload)
+
+    return payload
